'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

var _ramda = require('ramda');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var triples = [];
var previous = null;
var found = false;

function getTriple(line) {
    var _line$split = line.split('> ', 3),
        _line$split2 = (0, _slicedToArray3.default)(_line$split, 3),
        subject = _line$split2[0],
        verb = _line$split2[1],
        complement = _line$split2[2];

    subject += '>';
    verb += '>';
    if (complement === '.\n') {
        var _verb$split = verb.split(' ', 2);
        // In the case of a verb badly parsed (ex: <uri1> a <uri2>)


        var _verb$split2 = (0, _slicedToArray3.default)(_verb$split, 2);

        verb = _verb$split2[0];
        complement = _verb$split2[1];
    } else if (!complement.endsWith('" .\n')) {
        // In the case of an URI, split removed the end of the complement
        complement += '>';
    } else /* if (complement.endsWith(' .\n')) */{
            // In the normal case
            complement = complement.slice(0, -3); // Remove " .\n"
        }
    return [subject, verb, complement];
}

function ISTEXRemoveIf(data, feed) {
    var _getParam$split = this.getParam('if', ' = ').split(' = '),
        _getParam$split2 = (0, _slicedToArray3.default)(_getParam$split, 2),
        property = _getParam$split2[0],
        value = _getParam$split2[1];

    var toRemove = this.getParam('remove', []);
    function writeFilteredTriples() {
        if (found) {
            triples = triples.filter(function (triple) {
                return !(0, _ramda.contains)(triple.verb, toRemove);
            });
        }
        triples.forEach(function (t) {
            return feed.write(t.subject + ' ' + t.verb + ' ' + t.complement + ' .\n');
        });
    }

    if (this.isLast()) {
        writeFilteredTriples();
        return feed.close();
    }
    if (this.isFirst()) {
        triples = [];
        previous = null;
        found = false;
    }

    var _getTriple = getTriple(data),
        _getTriple2 = (0, _slicedToArray3.default)(_getTriple, 3),
        subject = _getTriple2[0],
        verb = _getTriple2[1],
        complement = _getTriple2[2];

    if (previous && subject !== previous) {
        writeFilteredTriples();
        triples = [];
        previous = subject;
        found = false;
    }
    triples.push({ subject: subject, verb: verb, complement: complement });
    found = found || verb === property && complement === value;
    feed.end();
}

/**
 * Remove triples which properties are given (`remove`) if other given `property`
 * has the given `value`.
 *
 * @param {string} if   "property = value"
 * @param {Array<string></string>} remove    list of properties to remove
 *
 * @example
 * <https://api.istex.fr/ark:/67375/QT4-D0J6VN6K-K> <https://data.istex.fr/ontology/istex#idIstex> "2FF3F5B1477986B9C617BB75CA3333DBEE99EB05" .
 * <https://api.istex.fr/ark:/67375/QT4-D0J6VN6K-K> a <http://purl.org/ontology/bibo/Document> .
 * <https://api.istex.fr/ark:/67375/QT4-D0J6VN6K-K> <host/genre> "journal" .
 * <https://api.istex.fr/ark:/67375/QT4-D0J6VN6K-K> <https://data.istex.fr/fake#journalTitle> "Linguistic Typology" .
 * <https://api.istex.fr/ark:/67375/QT4-D0J6VN6K-K> <https://data.istex.fr/fake#bookTitle> "Linguistic Typology" .
 * <https://api.istex.fr/ark:/67375/QT4-D0J6VN6K-K> <https://data.istex.fr/fake#seriesTitle> "Linguistic Typology" .
 *
 * @example
 * [ISTEXRemoveIf]
 * if = <host/genre> = "journal"
 * remove = <https://data.istex.fr/fake#bookTitle>
 * remove = <https://data.istex.fr/fake#seriesTitle>
 * remove = <host/genre>
 *
 * @example
 * <https://api.istex.fr/ark:/67375/QT4-D0J6VN6K-K> <https://data.istex.fr/ontology/istex#idIstex> "2FF3F5B1477986B9C617BB75CA3333DBEE99EB05" .
 * <https://api.istex.fr/ark:/67375/QT4-D0J6VN6K-K> a <http://purl.org/ontology/bibo/Document> .
 * <https://api.istex.fr/ark:/67375/QT4-D0J6VN6K-K> <https://data.istex.fr/fake#journalTitle> "Linguistic Typology" .
 */
exports.default = {
    ISTEXRemoveIf: ISTEXRemoveIf
};